@@ -9,7 +9,7 @@ use Bytes::Random::Secure qw(
   random_bytes random_bytes_base64 random_bytes_hex
 );
 
-our $VERSION = "0.03";
+our $VERSION = "0.04";
 
 sub get_random_bits {
 
@@ -43,7 +43,7 @@ sub get_flake {
     my $flake = $timestamp->blsft(23);
     $flake->bior($random);
 
-    return $flake->as_hex;
+    return substr( $flake->as_hex, 2);
 }
 
 
